@@ -4,7 +4,7 @@ use std::{
     io,
 };
 
-use structopt::StructOpt;
+use clap::Parser;
 use tune::{
     comma::{self, CommaCatalog},
     key::{Keyboard, PianoKey},
@@ -15,17 +15,17 @@ use tune::{
 
 use crate::App;
 
-#[derive(StructOpt)]
+#[derive(Parser)]
 pub(crate) struct EstOptions {
     /// Size of the interval to analyze
     step_size: Ratio,
 
     /// Odd limit for val output
-    #[structopt(long = "limit", default_value = "13")]
+    #[clap(long = "limit", default_value = "13")]
     odd_limit: u8,
 
     /// Error threshold for subgroup determination
-    #[structopt(long = "error", default_value = "25c")]
+    #[clap(long = "error", default_value = "25c")]
     error_threshold: Ratio,
 }
 
@@ -41,6 +41,7 @@ impl EstOptions {
         let stretch = temperament.size_of_octave().deviation_from(Ratio::octave());
 
         printer.print_headline(temperament.num_steps_per_octave(), stretch)?;
+        printer.print_basic_information(self.step_size)?;
 
         printer.print_newline()?;
 
@@ -105,6 +106,15 @@ impl<'a, 'b> EstPrinter<'a, 'b> {
         ))
     }
 
+    fn print_basic_information(&mut self, step_size: Ratio) -> io::Result<()> {
+        let fret_constant = step_size.as_float() / (step_size.as_float() - 1.0);
+        self.app.writeln(format_args!(
+            "- step size: {:#}\n\
+             - fret constant: {:.3}",
+            step_size, fret_constant,
+        ))
+    }
+
     fn print_val(&mut self, odd_limit: u8, threshold: Ratio) -> io::Result<()> {
         let val = &self.val;
 
